/*
Copyright 2015 The Kubernetes Authors All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package chart

import (
	"testing"
)

const badChart = "testdata/badchartversion/Chart.yaml"

func TestLoadChartfile(t *testing.T) {
	f, err := LoadChartfile(testfile)
	if err != nil {
		t.Errorf("Failed to open %s: %s", testfile, err)
		return
	}

	if f.Name != "frobnitz" {
		t.Errorf("Expected frobnitz, got %s", f.Name)
	}

	if len(f.Maintainers) != 2 {
		t.Errorf("Expected 2 maintainers, got %d", len(f.Maintainers))
	}

	if f.Source[0] != "https://example.com/foo/bar" {
		t.Errorf("Expected https://example.com/foo/bar, got %s", f.Source)
	}
}

func TestLoadChartfileFailsWithInvalidVersion(t *testing.T) {
	f, err := LoadChartfile(badChart)
	if err == nil {
		t.Errorf("LoadChartFile didn't fail with invalid version")
		return
	}
	if err.Error() != "Invalid Semantic Version" {
		t.Errorf("LoadChartFile didn't return the expected error")
		return
	}
	if f != nil {
		t.Errorf("LoadChartFile returned a chart despite error")
		return
	}
}
